<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class INFINEXIA_Gateway_Paiement extends WC_Payment_Gateway
{
    /**
     * Class constructor
     */
    public function __construct()
    {
        $this->id = 'infinexia';
        $this->method_title = __('Infinexia Gateway', 'infinexia-gateway');
		// Check if we are on the WooCommerce payment gateways page
        $current_screen = get_current_screen();
        if ($current_screen && $current_screen->id === 'woocommerce_page_wc-settings' && isset($_GET['tab']) && $_GET['tab'] === 'checkout' && isset($_GET['section']) && $_GET['section'] === $this->id) {
            // Do nothing or set specific properties for the settings page
            
        } else {
            // Display the method description for other pages
        $this->method_description = __('Accept payments from your WooCommerce easily and securely via <a href="https://infinexia.com">Infinexia</a>.', 'infinexia-gateway');

        }
		
        $this->has_fields = true;

        $this->supports = array(
            'products',
        );

        $this->init_form_fields();
        $this->init_settings();

        $this->title = $this->get_option('title');
        $this->description = $this->get_option('description');
        $this->instructions = $this->get_option('instructions');
    

        add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));

        add_action('woocommerce_receipt_' . $this->id, array($this, 'receipt_page'));


        add_action('wp_enqueue_scripts', array($this, 'payment_scripts'));
        add_action('admin_footer', array($this,'setting_script'));
    }

    public function setting_script() {
    ?>
    <script>
        jQuery(document).ready(function ($) {
            // Votre code JavaScript existant
            $("#woocommerce_infinexia_frais").parent().find(".description").css("color", "red");
            $("#woocommerce_infinexia_frais").attr("step", "0.01");
             $("#woocommerce_infinexia_frais").attr("min", <?php echo $this->get_option("default_min_fee") ?>);
            
           

            // Ajout du nouveau script pour afficher/masquer les champs en fonction des cases à cocher
            function toggleFields() {
                var enableWalletsChecked = $("#woocommerce_infinexia_enabled_fiat").is(":checked");
                var enableWalletsCryptoChecked = $("#woocommerce_infinexia_enabled_crypto").is(":checked");

                // Afficher ou masquer le champ enable_wallets
                if (enableWalletsChecked) {
                    $("#woocommerce_infinexia_enabled_fiat").closest("tr").next().show();
                } else {
                    $("#woocommerce_infinexia_enabled_fiat").closest("tr").next().hide();
                }

                // Afficher ou masquer le champ enable_wallets_crypto
                if (enableWalletsCryptoChecked) {
                    $("#woocommerce_infinexia_enabled_crypto").closest("tr").next().show();
                } else {
                    $("#woocommerce_infinexia_enabled_crypto").closest("tr").next().hide();
                }
            }

            // Appeler la fonction lors du chargement de la page
            toggleFields();
		

            // Ajouter des écouteurs d'événements pour détecter les changements dans les cases à cocher
            $("#woocommerce_infinexia_enabled_fiat, #woocommerce_infinexia_enabled_crypto").change(function () {
                toggleFields();
            });

            // Activer Select2 avec la prise en charge du HTML pour le champ de sélection des langues
            // $('#languages').select2({
            //     escapeMarkup: function (markup) {
            //         return markup;
            //     },
            //     templateResult: function (data) {
            //         return data.text;
            //     },
            //     templateSelection: function (data) {
            //         return data.text;
            //     }
            // });
        });

        // Activer Select2 après que la page ait été entièrement chargée
        $(window).on('load', function () {
            // $('#languages').select2({
            //     escapeMarkup: function (markup) {
            //         return markup;
            //     },
            //     templateResult: function (data) {
            //         return data.text;
            //     },
            //     templateSelection: function (data) {
            //         return data.text;
            //     }
            // });
        });
    </script>
    <?php
}


    public function getFee($data = ["fee" => "2.5"]){
        return $data["fee"];
    }


    function receipt_page($order)
    {
    }


    /**
     * Initialise Gateway Settings Form Fields.
     */
    public function init_form_fields()
    {
        $data = INFINEXIA_GATEWAY_Helpers::getData($this->get_option("merchant_id"), $this->get_option("api_key"));
        $languages = array(			
			'en_US' => plugins_url('../img/en.png', __FILE__) . '***English',
            'fr_FR' => plugins_url('../img/fr.png', __FILE__) . '***Français',
            'es_ES' => plugins_url('../img/es.png', __FILE__) . '***Español',
            'de_DE' => plugins_url('../img/de.png', __FILE__) . '***Deutsch', 
            'pt_PT' => plugins_url('../img/pt.png', __FILE__) . '***Português',
			);

        $fee =  $this->getFee($data);
        
        $this->update_option("default_min_fee",$fee);
        $this->form_fields = array(
            'main_title' => array(
               'type'  => 'title',
               'title' => '<img src="' . plugins_url('../img/Infinexia-Business.png', __FILE__) . '" alt="infinexia-gateway" style="max-height: 50px; width: auto;"/>',
            ),
            'logo_description' => array(
                'title' => '<span style="font-size: 16px; font-weight: bold;">' . __('Infinexia API Settings', 'infinexia-gateway'). '</span>',
                'type' => 'hidden',
				'class' => "subtitle",
                 'custom_attributes' => array(
                    'style' => 'font-size: 22px; font-weight: bold;', // Ajoutez ces styles CSS
                ), 
            ),
            'enabled' => array(
                'title'       => __('Enable/Disable', 'infinexia-gateway'),
                'label'       => __('Enable Infinexia Gateway', 'infinexia-gateway'),
                'type'        => 'checkbox',
                'description' => '',
                'default'     => 'no',
            ),
            'merchant_id' => array(
                'title'       => 'Api Id',
                'type'        => 'text',
				'description' => __('You will find the Api ID in the API settings of your account.', 'infinexia-gateway'),
				'desc_tip'    => true,
                'class'    => "kl-input",
            ),
            'api_key' => array(
                'title'       => 'Api Key',
                'type'        => 'password',
				'description' => __('You will find the Api Key in the API settings of your account.', 'infinexia-gateway'),
				'desc_tip'    => true,
                'class'    => "kl-input",
            ),
			'frais' => array(
                'title'       => __('Fees', 'infinexia-gateway'),
                'type'        => 'number',
                'description' => 'Minimum Gateway Fee : '.$fee.'%',
                'default'     =>  $fee,
                'min'     =>  $fee,
                'class'    => "kl-input kl-fee",
            ),
			               
            'settings_description' => array(
                'title' => '<span style="font-size: 16px; font-weight: bold;">' . __('Settings', 'infinexia-gateway'). '</span>',
                'type' => 'hidden',
                'class' => "subtitle",
			    'custom_attributes' => array(
                    'style' => 'font-size: 22px; font-weight: bold;', // Ajoutez ces styles CSS
                ), 
            ),
            'title' => array(
                'title'       => __('Title', 'infinexia-gateway'),
                'type'        => 'text',
                'description' => 'This is the title which the user sees during checkout.',__('Infinexia Gateway', 'infinexia-gateway'),
				'desc_tip'    => true,
				'placeholder' => __('Pay with', 'infinexia-gateway'),
                'default'     => __('Pay with', 'infinexia-gateway'),
                'class'    => "kl-input",
            ),
            'description' => array(
                'title'       => __('Description', 'infinexia-gateway'),
                'type'        => 'textarea',
                'description' => __('This is the description which the user sees during checkout.', 'infinexia-gateway'),
				'placeholder' => __('Pay with infinexia', 'infinexia-gateway'),
                'default'     => __('Pay with infinexia', 'infinexia-gateway'),
                'desc_tip'    => true,
                'class'    => "kl-input",
            ),
			'payment_title' => array(
                'title'       => __('Payment title', 'infinexia-gateway'),
                'type'        => 'text',
                'description' => __('This is the description which the user sees during checkout.', 'infinexia-gateway'),
				'placeholder' => __('Choose a currency', 'infinexia-gateway'),
                'default'     => __('Choose a currency', 'infinexia-gateway'),
                'desc_tip'    => true,
                'class'    => "kl-input",
            ),

            'assets_description' => array(
                'title' => '<span style="font-size: 16px; font-weight: bold;">' . __('Curencies', 'infinexia-gateway') . '</span>',
                'type' => 'hidden',
                'class' => "subtitle",
				'custom_attributes' => array(
                    'style' => 'font-size: 20px; font-weight: bold;', // Ajoutez ces styles CSS
                ), 
            ),
			'enabled_fiat' => array(
                'title'       => __('Fiat Currencies', 'infinexia-gateway'),
                'label'       => __('Enable Fiat Currencies', 'infinexia-gateway'),
                'type'        => 'checkbox',
                'description' => __('When enabled, you will be able to choose to accept payment in fiat currency.', 'infinexia-gateway'),
                'desc_tip' => true,
				'default'     => 'no',
            ),
            "enable_wallets" => array(
                'title' => __('Choose Fiat Currencies', 'infinexia-gateway'),
                'type' => 'multiselect',
                'description' => __('Choose the currencies you accept', 'infinexia-gateway'),
                'desc_tip' => true,
                'id'    => 'wallet_permissed',
                'class'    => "kl-select kl-input",
                'options' => INFINEXIA_GATEWAY_Helpers::getAvailaibleWallet($data["assets"]),
			),
			'enabled_crypto' => array(
                'title'       => __('Crypto Currencies', 'infinexia-gateway'),
                'label'       => __('Enable Crypto Currencies', 'infinexia-gateway'),
                'type'        => 'checkbox',
                'description' => __('When enabled, you will be able to choose to accept payment in cryptocurrency.', 'infinexia-gateway'),
				'desc_tip' => true,
				'id'    => 'woocommerce_infinexia_enabled_crypto',
                'default'     => 'no',
            ),
            "enable_wallets_crypto" => array(
                'title' => __('Choose Crypto Currencies', 'infinexia-gateway'),
                'type' => 'multiselect',
                'description' => __('Choose the currencies you accept', 'infinexia-gateway'),
                'desc_tip' => true,
                'id'    => 'woocommerce_infinexia_enable_wallets_crypto',
                'class'    => "kl-select kl-input",
                'options' => INFINEXIA_GATEWAY_Helpers::getAvailaibleWallet($data["assets"],"crypto")

            ),
        );
    }

    /**
     * Is gateway available
     * @return boolean
     */
    public function is_available()
    {
        return apply_filters('infinexia_payment_is_available', parent::is_available());
    }

    /**
     * Get gateway icon.
     * @return string
     */
    public function get_icon()
    {

        $icon_html = '<img src="' . plugins_url('../img/Logo-Infinexia-Full.png', __FILE__) . '" alt="infinexia-gateway" style="margin-left: 0px;max-height: 30px" />';

        return apply_filters('woocommerce_gateway_icon', $icon_html, $this->id);
    }


    /**
     * Return the gateway's pay button ID.
     *
     * @since 3.9.0
     * Is $order_id a subscription?
     * @param  int  $order_id
     * @return boolean
     */
    protected function is_subscription($order_id)
    {
        return (function_exists('wcs_order_contains_subscription') && (wcs_order_contains_subscription($order_id) || wcs_is_subscription($order_id) || wcs_order_contains_renewal($order_id)));
    }

    public function process_payment($order_id)
    {
        global $woocommerce;
        $order = wc_get_order($order_id);
        $infinexia_wallet_id = $_POST["infinexia_wallet"];
        if (!isset($infinexia_wallet_id)) {
            wc_add_notice('Please select a currency.', 'error');
            return;
        }
        $transaction_id  = INFINEXIA_GATEWAY_Helpers::savePaymentData($order_id, $infinexia_wallet_id, $order->get_checkout_order_received_url(), $order->get_checkout_order_received_url(), wc_get_checkout_url() . "?kp_error=payment_erro");
        $data = INFINEXIA_GATEWAY_Helpers::initialize_payment($order_id);
       
        if (isset($data["payment_url"])) {
            update_post_meta($order_id, "infinexia_payment_token", ["url" => $data["payment_url"], "token" => $data["token"], "transaction_id" => $transaction_id]);
            // INFINEXIA_GATEWAY_Helpers::checkStatus($order);
        } else {

            wc_add_notice('An error has occurred.', 'error');
            return;
        }

        return array('result' => 'success', 'redirect' => $data["payment_url"]);
    }

    public function generate_payment_form($order_id)
    {
        global $woocommerce;

        $data = get_post_meta($order_id, "infinexia_payment_token", true);
        if ($data != false && is_array($data)) {
            return '<script> window.location = "' . $data['url'] . '"</script>';
        }
    }

    public function process_refund($order_id, $amount = null, $reason = '')
    {
        return null;
    }

    public function payment_scripts()
    {
    }

    public function payment_fields()
    {
        $all_wallets = $this->form_fields['enable_wallets']['options'];
$all_wallets = array_merge($this->form_fields['enable_wallets_crypto']['options'],$all_wallets);
        $titles = [];
        $images = [];

        foreach ($all_wallets as $title => $img_url) {
            $titles[] = $title;
          
        }

        // I will echo() the form, but you can close PHP tags and print it directly in HTML
        echo '<fieldset id="wc-' . esc_attr($this->id) . '-cc-form" class="wc-credit-card-form wc-payment-form" style="background:transparent;">';

        // Add this action hook if you want your custom payment gateway to support it
        do_action('woocommerce_credit_card_form_start', $this->id);

        echo '
            <style>
                .select2-container{
                    width: 100% !important;
                }
				.kl-input{
					width: 100%;
					height: 50px;
					padding-left: 10px !important;
					border-radius: 3px;
				}
				.kl-width{
					    width: 25px;
						float: left !important;
						padding: 2px !important;
						margin-top: 3px;
				}
                
                select {
                    width: 99% !important;
                }
				
				.subtitle {
					color: #1d2327 !important;
                    font-size: 22px !important;
                    font-weight: bold !important;
					margin: 1em 0;
				}
				
				.kl-rigth{
					justify:right;
				}

			</style>
            '.(!empty($this->get_option("description"))  ?  "<p>".$this->get_option("description")." <p>" : ""  ).'</p>
            <div class="form-row form-row-wide">
                <label>'.$this->get_option("payment_title").' <span class="required">*</span></label>
                <select id="id-selected-wallet" data-placeholder="Choose a currency" name="infinexia_wallet" class="kl-select-wallet">';
        $fiats = (array) $this->get_option("enable_wallets");
        $cryptos =(array) $this->get_option("enable_wallets_crypto");
        $enable_fiat = $this->get_option("enabled_fiat");
        $enable_crypto = $this->get_option("enabled_crypto");
        $enables = [];
        if($enable_fiat == "yes") $enables = array_merge($fiats,$enables);
        if($enable_crypto  == "yes") $enables = array_merge($cryptos,$enables);

      
        foreach ($all_wallets as $title => $img_url) {
            if (!in_array($title, $enables)) continue;
            $url = explode("***", $img_url);
            $img_url = $url[0];

            echo "<option value='" . $title . "' data-img-src='" . $img_url . "'><b class='kl-rigth'>" . $title . "</b></option>";
        }

        echo "
                </select>
            </div>
            <script>
            select2SelectWallet();
            </script>
        ";
    }
}